@@ -1,29 +1,29 @@
 package Git::Class::Worktree;
 
-use Any::Moose; with qw/
+use Moo; with qw/
   Git::Class::Role::Execute
   Git::Class::Role::Cwd
 /;
 use MRO::Compat;
-use File::Spec;
+use Path::Tiny;
 
 has no_capture => (is => 'rw');
 
 has '_path' => (
   is       => 'rw',
-  isa      => 'Str',
+#  isa      => 'Str',
   init_arg => 'path',
   required => 1,
   trigger  => sub {
     my ($self, $path) = @_;
-    $self->{path} = File::Spec->rel2abs($path);
+    $self->{path} = path($path);
     chdir $path;
   },
 );
 
 has '_cmd' => (
   is         => 'rw',
-  isa        => 'Git::Class::Cmd',
+#  isa        => 'Git::Class::Cmd',
   init_arg   => 'cmd',
   builder    => '_build__cmd',
   handles    => [qw(
@@ -50,8 +50,6 @@ sub DEMOLISH {
   chdir $self->_cwd if $self->_cwd;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
